@@ -17,4 +17,10 @@ test_that("mathString", {
   result <- mathString("9.27", "6.24", operation = "-", numDigits = 2, unit = "%")
   testthat::expect_equal(result, "3.03 \\%")
 
+  result <- mathString("-2", "1", operation = "+", numDigits = 2, unit = "%")
+  testthat::expect_equal(result, "-1.00 \\%")
+
+  result <- mathString("-2", "-1", operation = "-", numDigits = 2, unit = "%")
+  testthat::expect_equal(result, "-1.00 \\%")
+
 })
