@@ -7,9 +7,9 @@ test_that("sphericityValueString", {
   # create dataframe and add data with 3(Comp: neutral vs. comp vs. incomp) levels
   dat <- createDF(nVP = 50, nTrl = 1,
                   design = list("Comp" = c("neutral", "comp", "incomp")))
-  dat <- addDataDF(dat, RT = list("Comp_neutral" = c(510, 150, 100),
-                                  "Comp_comp"    = c(500, 150, 100),
-                                  "Comp_incomp"  = c(520, 150, 100)))
+  dat <- addDataDF(dat, RT = list("Comp neutral" = c(510, 150, 100),
+                                  "Comp comp"    = c(500, 150, 100),
+                                  "Comp incomp"  = c(520, 150, 100)))
 
   # ezANOVA
   aovRT <- ez::ezANOVA(dat, dv = .(RT), wid = .(VP), within = .(Comp),
